
Changelog
=========

0.0.8 (2020-04-27)
------------------

* Changed the ytt option to be a flag

0.0.7 (2020-03-27)
------------------

* Changed the default templating option to be Helm instead of ytt 


0.0.5 (2020-03-08)
------------------

* Dirty names are now transformed to make less likely that symbols break Argo

0.0.4 (2020-03-07)
------------------

* Refactoring and initial adaptation
* Inclusion of tests

0.0.0 (2020-03-07)
------------------

* First release on PyPI.
